#
# Conditional build:
%bcond_without	tests
# Don't turn on systems if test suite fails.
# Test suite works fine with bundled libs, so the only way
# to turn on system libs is to make sure test suite works
# with them, too.
%bcond_without	system_admesh
%bcond_without	system_poly2tri
%bcond_with	system_polyclipping
#
%define		admesh_ver		0.98.1
%define		perl_encode_locale_ver	1.05
%define		perl_threads_ver	2.00
#
%include	/usr/lib/rpm/macros.perl
Summary:	G-code generator for 3D printers (RepRap, Makerbot, Ultimaker etc.)
Summary(pl.UTF-8):	Generator G-code dla drukarek 3D (RepRap, Makerbot, Ultimaker itp.)
Name:		slic3r
Version:	1.2.9
Release:	8
License:	AGPL v3 (code), CC-BY (images)
Group:		Applications/Engineering
Source0:	https://github.com/alexrj/Slic3r/archive/%{version}.tar.gz
# Source0-md5:	05ac7b137cbb7b12f442776e4c12dcc2
Source1:	%{name}.desktop
Source2:	%{name}.appdata.xml
# Modify Build.PL so we are able to build this on Fedora
Patch0:		%{name}-buildpl.patch
# Don't warn for Perl >= 5.16
# Use /usr/share/slic3r as datadir
# Those two are located at the same place at the code, so the patch is merged
Patch1:		%{name}-nowarn-datadir.patch
Patch2:		%{name}-english-locale.patch
Patch3:		%{name}-linker.patch
Patch4:		%{name}-clipper.patch
Patch5:		boost-1.60.patch
Patch6:		%{name}-boolcast.patch
Patch7:		%{name}-opengl070.patch
Patch8:		%{name}-wxclose.patch
URL:		http://slic3r.org/
BuildRequires:	ImageMagick
BuildRequires:	boost-devel
BuildRequires:	desktop-file-utils
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.80
BuildRequires:	perl(ExtUtils::ParseXS) >= 3.22
BuildRequires:	perl(ExtUtils::Typemaps::Default) >= 1.05
BuildRequires:	perl(Growl::GNTP) >= 0.15
BuildRequires:	perl(Math::ConvexHull) >= 1.0.4
BuildRequires:	perl(Math::Geometry::Voronoi) >= 1.3
BuildRequires:	perl(Math::PlanePath) >= 53
BuildRequires:	perl(Module::Build::WithXSpp) >= 0.14
BuildRequires:	perl(Moo) >= 1.003001
BuildRequires:	perl-Class-XSAccessor
BuildRequires:	perl-Encode-Locale >= %{perl_encode_locale_ver}
BuildRequires:	perl-ExtUtils-Typemap
BuildRequires:	perl-IO-stringy
BuildRequires:	perl-Math-ConvexHull-MonotoneChain
BuildRequires:	perl-SVG
BuildRequires:	perl-Wx
BuildRequires:	perl-XML-SAX
BuildRequires:	perl-XML-SAX-ExpatXS
BuildRequires:	perl-devel >= 1:5.8.0
BuildRequires:	perl-modules
BuildRequires:	perl-threads >= %{perl_threads_ver}
%{?with_system_poly2tri:BuildRequires:	poly2tri-devel}
%{?with_system_polyclipping:BuildRequires:	polyclipping-devel >= 6.2.9}
BuildRequires:	rpm-perlprov >= 4.1-13
%if %{with system_admesh}
BuildRequires:	admesh-devel >= %{admesh_ver}
Requires:	admesh-libs >= %{admesh_ver}
%endif
Requires:	perl-Encode-Locale >= %{perl_encode_locale_ver}
Requires:	perl-threads >= %{perl_threads_ver}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Slic3r is a G-code generator for 3D printers. It's compatible with
RepRaps, Makerbots, Ultimakers and many more machines. See the project
homepage at http://slic3r.org/ and the documentation on the Slic3r
wiki for more information.

%description -l pl.UTF-8
Slic3r to generator G-code dla drukarek 3D. Jest zgodny z urządzeniami
RepRap, Makerbot, Ultimaker i wieloma innymi. Więcej informacji można
znaleźć na stronie projektu http://slic3r.org/ oraz na wiki projektu
Slic3r.

%prep
%setup -qn Slic3r-%{version}

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%{?with_system_polyclipping:%patch4 -p1}
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

# Remove bundled admesh, clipper, poly2tri and boost
%{?with_system_admesh:%{__rm} -r xs/src/admesh}
%{?with_system_polyclipping:%{__rm} xs/src/clipper.*pp}
%{?with_system_poly2tri:%{__rm} -r xs/src/poly2tri}
%{__rm} -r xs/src/boost

%build
cd xs
%{?with_system_admesh:SYSTEM_ADMESH=1} \
%{?with_system_polyclipping:SYSTEM_POLYCLIPPING=1} \
%{?with_system_poly2tri:SYSTEM_POLY2TRI=1} \
%{__perl} ./Build.PL \
	installdirs=vendor \
	optimize="%{rpmcflags}"
./Build
cd ..

%if %{with tests}
cd xs
./Build test verbose=1
cd -
SLIC3R_NO_AUTO=1 \
%{__perl} Build.PL \
	installdirs=vendor
# the --gui runs no tests, it only checks requires
%endif

# prepare pngs in mutliple sizes
for res in 16 32 48 128 256; do
  mkdir -p hicolor/${res}x${res}/apps
done
cd hicolor
convert ../var/Slic3r.ico %{name}.png
cp %{name}-0.png 256x256/apps/%{name}.png
cp %{name}-1.png 128x128/apps/%{name}.png
cp %{name}-2.png 48x48/apps/%{name}.png
cp %{name}-3.png 32x32/apps/%{name}.png
cp %{name}-4.png 16x16/apps/%{name}.png
rm %{name}-*.png
cd -

# To avoid "iCCP: Not recognized known sRGB profile that has been edited"
cd var
find . -type f -name "*.png" -exec convert {} -strip {} \;
cd -

%install
rm -rf $RPM_BUILD_ROOT
cd xs
./Build install destdir=$RPM_BUILD_ROOT create_packlist=0
cd -
find $RPM_BUILD_ROOT -type f -name '*.bs' -size 0 -exec rm -f {} \;

# I see no way of installing slic3r with it's build script
# So I copy the files around manually
install -d $RPM_BUILD_ROOT%{_bindir}
install -d $RPM_BUILD_ROOT%{perl_vendorlib}
install -d $RPM_BUILD_ROOT%{_datadir}/%{name}
install -d $RPM_BUILD_ROOT%{_datadir}/icons
install -d $RPM_BUILD_ROOT%{_datadir}/appdata

cp -a %{name}.pl $RPM_BUILD_ROOT%{_bindir}/%{name}
cp -a lib/* $RPM_BUILD_ROOT%{perl_vendorlib}

cp -a var/* $RPM_BUILD_ROOT%{_datadir}/%{name}
cp -r hicolor $RPM_BUILD_ROOT%{_datadir}/icons
desktop-file-install --dir=$RPM_BUILD_ROOT%{_desktopdir} %{SOURCE1}

cp %{SOURCE2} $RPM_BUILD_ROOT%{_datadir}/appdata/%{name}.appdata.xml

%{_fixperms} $RPM_BUILD_ROOT*

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_icon_cache hicolor

%postun
if [ $1 -eq 0 ] ; then
	%update_icon_cache hicolor
fi

%files
%defattr(644,root,root,755)
%doc README.md
%attr(755,root,root) %{_bindir}/%{name}
%{perl_vendorlib}/Slic3r*
%{perl_vendorarch}/Slic3r*
%{perl_vendorarch}/auto/Slic3r*
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_desktopdir}/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/%{name}
%changelog
* Fri Aug 31 2018 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/slic3r.git;a=log;h=master

* Fri Aug 31 2018 Jan Rękorajski <baggins@pld-linux.org> 7d72f89
- rebuild with perl 5.28.0
- release 8 (by relup.sh)

* Thu Jun 22 2017 Jan Rękorajski <baggins@pld-linux.org> a38a340
- added build fixes from fedora
- rel 7

* Sun Jun 11 2017 Jan Rękorajski <baggins@pld-linux.org> 578d028
- perl req/prov fix
- release 6 (by relup.sh)

* Sun Jun 11 2017 Jan Rękorajski <baggins@pld-linux.org> 829293f
- rebuild with perl 5.26
- release 5 (by relup.sh)

* Mon Oct 31 2016 Jan Rękorajski <baggins@pld-linux.org> 9308dc0
- fix building with boost 1.60+
- rel 4

* Sun Oct 30 2016 Jan Rękorajski <baggins@pld-linux.org> ed65aa5
- rebuild with perl 5.24.0
- release 3 (by relup.sh)

* Thu Dec 24 2015 Jan Rękorajski <baggins@pld-linux.org> c73f52d
- release 2 (by relup.sh)

* Sun Jul 05 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 29d09fc
- actually we want the other poly2tri

* Sat Jul 04 2015 Jakub Bogusz <qboosh@pld-linux.org> a705825
- pl, some cleanups, adjusted poly2tri-c package name

* Sun Jun 21 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 987c20e
- up to stable 1.2.9

* Wed Jun 10 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> b83ae0b
- lets call it rel 1

* Wed Jun 10 2015 Elan Ruusamäe <glen@delfi.ee> 118ed10
- more package names after installing deps

* Wed Jun 10 2015 Elan Ruusamäe <glen@delfi.ee> 88c543e
- adapter, use package names (most of them in perl core distribution)

* Wed Jun 10 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> f8c1bd8
- up to 1.2.8

* Tue Jun 09 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 424bbfd
- perl deps

* Tue Jun 09 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 1320a91
- 1.2.7; builds but still needs ton of work

* Fri May 15 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 650c865
- initial, unfinished, from FC

